KeyGenResult

Struct KeyGenResult 

pub struct KeyGenResult {
    pub key_id: String,
    pub public_key_der: Vec<u8>,
    pub wrapped_private_key: Option<Vec<u8>>,
}
Result of a server-side key generation request.

Fields

key_id: String

KRA key identifier for the archived key.

public_key_der: Vec<u8>

DER-encoded public key.

wrapped_private_key: Option<Vec<u8>>

Wrapped (encrypted) private key bytes, if returned.

The wrapping key is typically the transport certificate of the requesting agent. The EST client must unwrap this using the corresponding private key.